@@ -3,23 +3,24 @@ Code to poll for realtime changes
 """
 
 import os
-import requests
+import aikido_zen.background_process.requests as requests
 from aikido_zen.helpers.logging import logger
-
-api_url = "https://guard.aikido.dev/"
+from aikido_zen.helpers.urls.get_api_url import get_api_url
 
 
 def get_realtime_url():
     """Fetches the default realtime url or environment variable"""
-    realtime_url = os.getenv("AIKIDO_REALTIME_URL")
+    realtime_url = os.getenv("AIKIDO_REALTIME_ENDPOINT")
     if realtime_url is not None:
+        if not realtime_url.endswith("/"):
+            realtime_url += "/"
         return realtime_url
     return "https://runtime.aikido.dev/"
 
 
 def get_config(token):
     """Fetches the config from realtime URL"""
-    url = f"{api_url}api/runtime/config"
+    url = get_api_url() + "api/runtime/config"
     headers = {
         "Authorization": str(token),
     }
@@ -42,4 +43,6 @@ def get_config_last_updated_at(token):
     if response.status_code != 200:
         logger.info("Invalid response from realtime api : %s", response.status_code)
 
-    return int(response.json()["configUpdatedAt"])  #  Return configUpdatedAt time
+    return int(
+        response.json().get("configUpdatedAt", 0)
+    )  #  Return configUpdatedAt time
