@@ -65,12 +65,14 @@ def test_wsgi_context_1():
         "route": "/hello",
         "subdomains": [],
         "user": None,
+        "rate_limit_group": None,
         "remote_address": "198.51.100.23",
         "parsed_userinput": {},
         "xml": {},
         "outgoing_req_redirects": [],
         "executed_middleware": False,
         "route_params": [],
+        "protection_forced_off": None,
     }
     assert context.get_user_agent() is None
 
@@ -95,12 +97,14 @@ def test_wsgi_context_2():
         "route": "/hello",
         "subdomains": [],
         "user": None,
+        "rate_limit_group": None,
         "remote_address": "198.51.100.23",
         "parsed_userinput": {},
         "xml": {},
         "outgoing_req_redirects": [],
         "executed_middleware": False,
         "route_params": [],
+        "protection_forced_off": None,
     }
     assert context.get_user_agent() == "Mozilla/5.0"
 
@@ -282,3 +286,13 @@ def test_set_valid_json_with_special_characters_bytes():
     context = Context(req=basic_wsgi_req, body=None, source="flask")
     context.set_body(b'{"key": "value with special characters !@#$%^&*()"}')
     assert context.body == {"key": "value with special characters !@#$%^&*()"}
+
+
+def test_set_protection_forced_off():
+    context = Context(req=basic_wsgi_req, body=None, source="flask")
+    context.set_force_protection_off(True)
+    assert context.protection_forced_off is True
+    context.set_force_protection_off(False)
+    assert context.protection_forced_off is False
+    context.set_force_protection_off(None)
+    assert context.protection_forced_off is None
