@@ -16,7 +16,9 @@ import aikido_zen.background_process.comms as comm
 from aikido_zen.helpers.logging import logger
 from aikido_zen.helpers.get_clean_stacktrace import get_clean_stacktrace
 from aikido_zen.helpers.blocking_enabled import is_blocking_enabled
-from aikido_zen.helpers.protection_forced_off import protection_forced_off
+from aikido_zen.helpers.is_protection_forced_off_cached import (
+    is_protection_forced_off_cached,
+)
 from aikido_zen.thread.thread_cache import get_cache
 from .sql_injection.context_contains_sql_injection import context_contains_sql_injection
 from .nosql_injection.check_context import check_context_for_nosql_injection
@@ -35,6 +37,10 @@ def run_vulnerability_scan(kind, op, args):
     raises error if blocking is enabled, communicates it with connection_manager
     """
     context = get_current_context()
+
+    if is_protection_forced_off_cached(context):
+        return
+
     comms = comm.get_comms()
     thread_cache = get_cache()
     if not context and kind != "ssrf":
@@ -47,11 +53,6 @@ def run_vulnerability_scan(kind, op, args):
         # This is because some scans/tests for SSRF do not require a thread cache to be set.
         return
     if thread_cache and context:
-        if protection_forced_off(
-            context.get_route_metadata(), thread_cache.get_endpoints()
-        ):
-            #  The client turned protection off for this route, not scanning
-            return
         if thread_cache.is_bypassed_ip(context.remote_address):
             #  This IP is on the bypass list, not scanning
             return
@@ -82,15 +83,12 @@ def run_vulnerability_scan(kind, op, args):
             )
             error_type = AikidoPathTraversal
         elif kind == "ssrf":
-            # args[0] : DNS Results, args[1] : Hostname, args[2] : Port
-            injection_results = inspect_getaddrinfo_result(
-                dns_results=args[0], hostname=args[1], port=args[2]
-            )
+            dns_results, hostname, port = args
+            injection_results = inspect_getaddrinfo_result(dns_results, hostname, port)
             error_type = AikidoSSRF
 
-            # Check that port number is higher than zero before reporting :
-            if comms and args[2] > 0:
-                comms.send_data_to_bg_process("HOSTNAMES_ADD", (args[1], args[2]))
+            if thread_cache and port > 0:
+                thread_cache.hostnames.add(hostname, port)
         else:
             logger.error(
                 "Vulnerability type %s currently has no scans implemented", kind
@@ -100,8 +98,13 @@ def run_vulnerability_scan(kind, op, args):
 
     if injection_results:
         logger.debug("Injection results : %s", serialize_to_json(injection_results))
+
         blocked = is_blocking_enabled()
+        operation = injection_results["operation"]
+        thread_cache.stats.on_detected_attack(blocked, operation)
+
         stack = get_clean_stacktrace()
+
         if comms:
             comms.send_data_to_bg_process(
                 "ATTACK", (injection_results, context, blocked, stack)
